.. Use python as the default language for syntax highlighting in this file
.. highlight:: python

.. default-domain:: py

boututils package
=================

Module contents
---------------

.. automodule:: boututils
    :members:
    :undoc-members:

Submodules
----------
boututils.analyse\_equil\_2 module
----------------------------------

.. automodule:: boututils.analyse_equil_2
    :members:
    :undoc-members:

boututils.anim module
---------------------

.. automodule:: boututils.anim
    :members:
    :undoc-members:

boututils.ask module
--------------------

.. automodule:: boututils.ask
    :members:
    :undoc-members:

boututils.boutarray module
--------------------------

.. automodule:: boututils.boutarray
    :members:
    :undoc-members:
    :show-inheritance:

boututils.boutgrid module
-------------------------

.. automodule:: boututils.boutgrid
    :members:
    :undoc-members:

boututils.boutwarnings module
-----------------------------

.. automodule:: boututils.boutwarnings
    :members:
    :undoc-members:

boututils.calculus module
-------------------------

.. automodule:: boututils.calculus
    :members:
    :undoc-members:

boututils.closest\_line module
------------------------------

.. automodule:: boututils.closest_line
    :members:
    :undoc-members:

boututils.crosslines module
---------------------------

.. automodule:: boututils.crosslines
    :members:
    :undoc-members:

boututils.datafile module
-------------------------

.. automodule:: boututils.datafile
    :members:
    :undoc-members:

boututils.efit\_analyzer module
-------------------------------

.. automodule:: boututils.efit_analyzer
    :members:
    :undoc-members:

boututils.fft\_deriv module
---------------------------

.. automodule:: boututils.fft_deriv
    :members:
    :undoc-members:

boututils.fft\_integrate module
-------------------------------

.. automodule:: boututils.fft_integrate
    :members:
    :undoc-members:

boututils.file\_import module
-----------------------------

.. automodule:: boututils.file_import
    :members:
    :undoc-members:

boututils.geqdsk module
-----------------------

.. automodule:: boututils.geqdsk
    :members:
    :undoc-members:

boututils.idl\_tabulate module
------------------------------

.. automodule:: boututils.idl_tabulate
    :members:
    :undoc-members:

boututils.int\_func module
--------------------------

.. automodule:: boututils.int_func
    :members:
    :undoc-members:

boututils.linear\_regression module
-----------------------------------

.. automodule:: boututils.linear_regression
    :members:
    :undoc-members:

boututils.local\_min\_max module
--------------------------------

.. automodule:: boututils.local_min_max
    :members:
    :undoc-members:

boututils.mode\_structure module
--------------------------------

.. automodule:: boututils.mode_structure
    :members:
    :undoc-members:

boututils.moment\_xyzt module
-----------------------------

.. automodule:: boututils.moment_xyzt
    :members:
    :undoc-members:

boututils.options module
------------------------

.. automodule:: boututils.options
    :members:
    :undoc-members:

boututils.plotdata module
-------------------------

.. automodule:: boututils.plotdata
    :members:
    :undoc-members:

boututils.radial\_grid module
-----------------------------

.. automodule:: boututils.radial_grid
    :members:
    :undoc-members:

boututils.read\_geqdsk module
-----------------------------

.. automodule:: boututils.read_geqdsk
    :members:
    :undoc-members:

boututils.run\_wrapper module
-----------------------------

.. automodule:: boututils.run_wrapper
    :members:
    :undoc-members:

boututils.showdata module
-------------------------

.. automodule:: boututils.showdata
    :members:
    :undoc-members:

boututils.spectrogram module
----------------------------

.. automodule:: boututils.spectrogram
    :members:
    :undoc-members:

boututils.surface\_average module
---------------------------------

.. automodule:: boututils.surface_average
    :members:
    :undoc-members:

boututils.volume\_integral module
---------------------------------

.. automodule:: boututils.volume_integral
    :members:
    :undoc-members:

boututils.watch module
----------------------

.. automodule:: boututils.watch
    :members:
    :undoc-members:

